@@ -6,7 +6,7 @@ class NetcashGatewayAdmin(admin.ModelAdmin):
 
 class NetcashOrderAdmin(admin.ModelAdmin):
     list_display = ['Reference', 'created_at', 'updated_at', 'Amount',
-                    'Reason', 'RETC', 'request_ip', 'TransactionAccepted', 'trusted']
+                    'Reason', 'RETC', 'request_ip', 'TransactionAccepted', 'trusted', 'debug_info']
     list_filter = ['TransactionAccepted', 'trusted']
     search_fields = ['Reference']
     date_hierarchy = 'created_at'
